@@ -1,18 +1,24 @@
 import re
 from debian_linux.debian import Version
 
+
 class VersionXen(Version):
     _version_xen_rules = ur"""
 ^
 (?P<version>
     \d+\.\d+
 )
-\.\d+
 (?:
-    \+hg\d+
+    \.\d+
+    (?:
+        ~rc\d+
+    )?
+    (?:
+        \+hg-\d+.[a-z0-9]+
+    )?
     |
-    ~rc\d+
-)?
+    ~hg-\d+.[a-z0-9]+
+)
 -
 (?:[^-]+)
 $
@@ -27,5 +33,3 @@ $
         d = match.groupdict()
         self.xen_version = d['version']
 
-if __name__ == '__main__':
-    gencontrol()()
